Translations - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Translations

Betty ships with the following translations:

Dutch (`nl-NL`)

  Translations are 98% complete.

English (`en-US`)

  Translations are 100% complete.

French (`fr-FR`)

  Translations are 35% complete.

German (`de-DE`)

  Translations are 89% complete.

Ukrainian (`uk`)

  Translations are 32% complete.

Extensions and projects can override these translations through asset management.

Betty uses gettext to manage its translations. For each language, there must be a `./locale/$locale/LC_MESSAGES/betty.po` file that contains the translations for that language. These translations are compiled lazily whenever Betty needs them, so you won’t have to go through the trouble of creating `*.mo` files yourself.

Translations are loaded in the following order, where translations loaded later will override earlier translations:

1. Betty’s built-in translations

2. Translations provided by extensions in the order of their dependency tree

3. Project-specific translations found in your project’s assets directory

Read more about how to contribute to Betty’s built-in translations.